parse_nbt_path_argument

Function parse_nbt_path_argument 

pub fn parse_nbt_path_argument(
    input: &str,
) -> Result<(NbtPath, usize), NbtPathError>
Parses one NBT path and returns the byte cursor consumed by it.

Errors

Returns an error when the input does not start with a valid NBT path.