NbtPath

Struct NbtPath 

pub struct NbtPath {
    original: String,
    nodes: Vec<NbtPathNodeEntry>,
}
Parsed vanilla NBT path.

Fields

original: Stringnodes: Vec<NbtPathNodeEntry>

Implementations

Source

impl NbtPath

pub fn as_str(&self) -> &str

Returns the path as written in command input.

pub fn get(&self, tag: &NbtTag) -> Vec<NbtTag>

Returns cloned tags selected by this path.

pub fn count_matching(&self, tag: &NbtTag) -> usize

Returns the number of tags matched by this path.

pub fn set( &self, tag: &mut NbtTag, value: NbtTag, ) -> Result<usize, NbtPathMutationError>

Sets every tag selected by this path to value.

Missing intermediate compound/list parents are created the same way vanilla’s NbtPathArgument.NbtPath#set creates them. The return value is the number of changed target tags.

Errors

Returns an error if an intermediate path node cannot resolve or if the inserted value would exceed vanilla’s maximum NBT depth.

fn set_at( &self, tag: &mut NbtTag, node_index: usize, value: &NbtTag, ) -> Result<SetOutcome, NbtPathMutationError>